"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.HttpHelper = void 0;
const errors_1 = require("../errors");
const lodash_1 = require("lodash");
// Enums
const httpStatus_1 = require("../common/enums/httpStatus");
const mediaType_1 = require("../common/enums/mediaType");
class HttpHelper {
    static jsonResponse(res, code, message) {
        res.status(code).json({ message });
    }
    static ok(res, dto, allowedFields) {
        if (dto) {
            res.type(mediaType_1.MediaTypes.JSON);
            if (allowedFields && Array.isArray(allowedFields)) {
                res.status(httpStatus_1.HttpStatus.OK).json(lodash_1.pick(dto, allowedFields));
            }
            else {
                res.status(httpStatus_1.HttpStatus.OK).json(dto);
            }
        }
        else {
            res.sendStatus(httpStatus_1.HttpStatus.OK);
        }
    }
    static created(res, dto, allowedFields) {
        if (dto) {
            res.type(mediaType_1.MediaTypes.JSON);
            if (allowedFields && Array.isArray(allowedFields)) {
                res.status(httpStatus_1.HttpStatus.CREATED).json(lodash_1.pick(dto, allowedFields));
            }
            else {
                res.status(httpStatus_1.HttpStatus.CREATED).json(dto);
            }
        }
        else {
            res.sendStatus(httpStatus_1.HttpStatus.CREATED);
        }
    }
    static clientError(res, message) {
        HttpHelper.jsonResponse(res, httpStatus_1.HttpStatus.BAD_REQUEST, message ? message : 'Bad request');
    }
    static unauthorized(res, message) {
        HttpHelper.jsonResponse(res, httpStatus_1.HttpStatus.UNAUTHORIZED, message ? message : 'Unauthorized');
    }
    static paymentRequired(res, message) {
        HttpHelper.jsonResponse(res, httpStatus_1.HttpStatus.PAYMENT_REQUIRED, message ? message : 'Payment required');
    }
    static forbidden(res, message) {
        HttpHelper.jsonResponse(res, httpStatus_1.HttpStatus.FORBIDDEN, message ? message : 'Forbidden');
    }
    static notFound(res, message) {
        HttpHelper.jsonResponse(res, httpStatus_1.HttpStatus.NOT_FOUND, message ? message : 'Not found');
    }
    static conflict(res, message) {
        HttpHelper.jsonResponse(res, httpStatus_1.HttpStatus.CONFLICT, message ? message : 'Conflict');
    }
    static tooMany(res, message) {
        HttpHelper.jsonResponse(res, httpStatus_1.HttpStatus.TOO_MANY_REQUESTS, message ? message : 'Too many requests');
    }
    static fail(res, error) {
        if (error instanceof errors_1.BaseError) {
            const { httpStatus, code, message } = error;
            res.status(httpStatus || httpStatus_1.HttpStatus.INTERNAL_SERVER_ERROR).json({
                code: code || 'ihub.uncaughtException',
                message,
            });
        }
        else {
            res.status(httpStatus_1.HttpStatus.INTERNAL_SERVER_ERROR).json({
                message: error.toString()
            });
        }
    }
}
exports.HttpHelper = HttpHelper;
//# sourceMappingURL=httpHelper.js.map