"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getStoreId = exports.userHasStore = exports.isSuperUser = void 0;
// Helpers
const objectHelper_1 = require("./objectHelper");
// Utils
const stringUtils_1 = require("../utils/stringUtils");
// Errors
const errors_1 = require("../errors");
function isSuperUser(user) {
    return Array.isArray(user.acl) && (user.acl.includes('Admin') || user.acl.includes('Root'));
}
exports.isSuperUser = isSuperUser;
function userHasStore(user, storeId) {
    return Array.isArray(user.stores) && user.stores.includes(storeId);
}
exports.userHasStore = userHasStore;
function getStoreId(req) {
    const { user } = req;
    const storeIdHeader = req.headers['x-ihub-storeid'];
    let storeId;
    if (user.type === 'integration') {
        storeId = req.user.stores[0];
    }
    else if (storeIdHeader) {
        if (storeIdHeader.includes(', ')) {
            throw new errors_1.BadRequestError('Just one X-IHUB-storeId header is allowed');
        }
        if (!isSuperUser(user) && !userHasStore(user, storeIdHeader)) {
            throw new errors_1.UnauthorizedError(`You don't have access to this store`);
        }
        if (!objectHelper_1.isValidObjectId(storeIdHeader)) {
            throw new errors_1.BadRequestError(`X-IHUB-storeId header isn't valid`);
        }
        storeId = storeIdHeader;
    }
    if (stringUtils_1.isBlank(storeId)) {
        throw new errors_1.BadRequestError(`X-IHUB-storeId header wasn't informed`);
    }
    return storeId;
}
exports.getStoreId = getStoreId;
//# sourceMappingURL=storeHelper.js.map