"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.utils = exports.helpers = exports.errors = exports.common = exports.CacheHelper = exports.models = exports.counter = exports.plugins = exports.tasks = exports.server = exports.database = exports.apm = exports.logger = exports.IhubFramework = void 0;
// Elastic APM should be started before any other module is required/imported.
require('./libs/env');
const serialize_error_1 = require("serialize-error");
const apm_1 = require("./apm");
Object.defineProperty(exports, "apm", { enumerable: true, get: function () { return apm_1.apm; } });
const lodash_1 = require("lodash");
const common = __importStar(require("./common"));
exports.common = common;
const errors = __importStar(require("./errors"));
exports.errors = errors;
const utils = __importStar(require("./utils"));
exports.utils = utils;
const helpers = __importStar(require("./helpers"));
exports.helpers = helpers;
const logger_1 = require("./logger");
const database_1 = require("./database");
const server_1 = require("./server");
const loader_1 = require("./loader");
const tasks_1 = require("./tasks");
const plugins_1 = require("./loader/plugins");
const shutdown_1 = require("./shutdown");
const counter_1 = require("./counter");
const cache_1 = require("./cache");
Object.defineProperty(exports, "CacheHelper", { enumerable: true, get: function () { return cache_1.CacheHelper; } });
// Initialize the counter, we use this to have control of our running process
const counter = new counter_1.Counter();
exports.counter = counter;
let logger;
exports.logger = logger;
let database;
exports.database = database;
const models = {};
exports.models = models;
let server;
exports.server = server;
let tasks;
exports.tasks = tasks;
let plugins;
exports.plugins = plugins;
class IhubFramework {
    /**
     * @param options: IhubFrameworkOptions
     */
    constructor(options) {
        this.options = {
            framework: {
                components: process.env.COMPONENTS_FOLDER || 'dist/components',
                models: process.env.MODELS_FOLDER || 'dist/models',
                plugins: process.env.PLUGINS_FOLDER || 'dist/plugins',
            },
            logger: {
                elastic: {
                    enabled: process.env.LOGGER_ELASTICSEARCH_ENABLED === 'true' ? true : false,
                    host: process.env.LOGGER_ELASTICSEARCH_URL,
                    log: 'error',
                    indexPrefix: `logs-${process.env.PROJECT_NAME}`,
                    level: process.env.LOGGER_ELASTICSEARCH_LEVEL || 'debug',
                },
                console: {
                    enabled: process.env.NODE_ENV === 'development' || false,
                    level: process.env.LOGGER_CONSOLE_LEVEL || 'debug',
                },
            },
            database: {
                enabled: process.env.DATABASE_ENABLED === 'true' ? true : false,
                connectionUrl: process.env.DATABASE_URI,
                useUnifiedTopology: process.env.DATABASE_USE_UNIFIED_TOPOLOGY === 'true' ? true : false,
            },
            server: {
                enabled: process.env.SERVER_HTTP_ENABLED === 'true' ? true : false,
                headers: [
                    {
                        prop: 'Access-Control-Allow-Origin',
                        value: '*',
                    },
                    {
                        prop: 'Access-Control-Allow-Methods',
                        value: '*',
                    },
                    {
                        prop: 'Access-Control-Allow-Headers',
                        value: '*',
                    },
                ],
                jwt: process.env.SERVER_HTTP_JWT_SECRET || 'secret123',
                http: {
                    port: process.env.SERVER_HTTP_PORT || '8888',
                },
            },
            tasks: {
                enabled: process.env.TASKS_ENABLED === 'true' ? true : false,
                host: process.env.TASKS_HOST || 'rabbit',
            },
        };
        this.options = lodash_1.merge(this.options, options);
    }
    /**
     * Validate if the minimum settings were provided to safely start the framework
     * @returns void
     */
    validate() {
        const { PROJECT_NAME } = process.env;
        if (counter.frameworkStarted) {
            throw new Error('Do not start more than on time');
        }
        if (!PROJECT_NAME) {
            throw new Error('Environment PROJECT_NAME is required');
        }
        counter.frameworkStarted = true;
    }
    /**
     * Starts the ihub
     * @returns void
     */
    async start() {
        try {
            this.validate();
            // Logger
            exports.logger = logger = new logger_1.Logger(this.options.logger);
            logger.info('iHub Framework is starting', 'ihf.bootup.starting');
            // Starts the database if enabled
            exports.database = database = await new database_1.Database(this.options.database).start();
            // Starts the server if enabled
            exports.server = server = await new server_1.Server(this.options.server).start();
            // Tasks TODO: Improve, this is ugly
            exports.tasks = tasks = await new tasks_1.Tasks(this.options.tasks).start();
            // Plugins
            exports.plugins = plugins = await new plugins_1.Plugins(this.options.framework.plugins).start();
            // Load the components
            await new loader_1.Loader(this.options).start();
            // Starts the gracefull shutdown
            shutdown_1.shutdown(server, database, tasks);
            // Changes the health check route status code
            if (server)
                server.healthz();
            logger.info('iHub Framework is up', 'ihf.bootup.success');
        }
        catch (error) {
            if (logger) {
                logger.error((error && error.message) ? error.message : error, 'ihf.bootup.error', {
                    error: serialize_error_1.serializeError(error),
                });
            }
            else {
                console.error((error && error.message) ? error.message : error);
            }
            process.exit(1);
        }
    }
}
exports.IhubFramework = IhubFramework;
if (require.main === module) {
    (async () => await new IhubFramework().start())();
}
__exportStar(require("./loader/component"), exports);
__exportStar(require("./request"), exports);
//# sourceMappingURL=index.js.map