"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Cron = void 0;
const cron_1 = __importDefault(require("cron"));
const cluster = require('cluster');
const uniqid = require('uniqid');
const cronValidator = require('cron-validator');
const index_1 = require("../../index");
__exportStar(require("./CronModel"), exports);
const CronJob = cron_1.default.CronJob;
class Cron {
    // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    constructor(routines, model) {
        this.crons = [];
        this.model = model;
        // Loads the routine
        routines.forEach(async (job) => {
            // Skips routine loading for non primary ou non master worker
            if ((process.env.NODE_APP_INSTANCE !== '0' && process.env.NODE_APP_INSTANCE !== undefined) || (cluster.worker && cluster.worker.id !== 1)) {
                return;
            }
            index_1.logger.debug(`Loading routine ${job.id}`, 'ihf.component.routines.loading');
            if (cronValidator.isValidCron(job.cron)) {
                // Check if it can't run at the same time
                if (!job.concurrently) {
                    const cronExists = await this.getCronControl(job.id);
                    // If there isn't any control doc we create it
                    if (!cronExists) {
                        try {
                            await new model({
                                jobId: job.id,
                            }).save();
                        }
                        catch (e) {
                            // TODO think what to to in case of error
                            // console.log(e)
                        }
                    }
                }
                // Lets give this job a unique id
                const runningId = uniqid();
                const cronJob = new CronJob(job.cron, async () => {
                    index_1.logger.info(`Job for ${job.id} started`, `ihf.component.routines.${job.id}.started`);
                    let apmTransaction = false;
                    if (process.env.APM_ENABLED === 'true')
                        apmTransaction = this.transStart(job.id);
                    // Update the control doc and get the non update return to see if it was already running
                    const start = await this.cronControlStart(job.id, runningId);
                    // Lets check the sla for any error
                    const sla = job.sla || 300000;
                    const cronControlRawDoc = await this.getCronControl(job.id);
                    if (cronControlRawDoc && cronControlRawDoc.running) {
                        const slaMSDelta = new Date().getTime() - new Date(cronControlRawDoc.startDate).getTime();
                        if (slaMSDelta > sla) {
                            index_1.logger.error(`Job for ${job.id} SLA error`, `ihf.component.routines.${job.id}.error`);
                            if (apmTransaction)
                                this.transEnd(apmTransaction);
                            return;
                        }
                    }
                    if (!start) {
                        index_1.logger.debug(`Job for ${job.id} skipped`, `ihf.component.routines.${job.id}.skipped`);
                        if (apmTransaction)
                            this.transEnd(apmTransaction);
                        return;
                    }
                    // Do the routine action
                    job.action(async () => {
                        const finish = await this.cronControlFinish(job.id, runningId);
                        if (apmTransaction)
                            this.transEnd(apmTransaction);
                        if (finish.jobRunningId !== runningId) {
                            index_1.logger.error('Job conc error', 'ihf.component.routines.conc.error');
                        }
                        index_1.logger.info(`Job for ${job.id} done`, `ihf.component.routines.${job.id}.done`);
                    });
                }, null, true, 'America/Sao_Paulo', null, job.runOnInit);
                cronJob.runningId = runningId;
                index_1.counter.crons.push(cronJob);
            }
            else {
                index_1.logger.error(`Invalid routine ${job.id} - ${job.cron}`, 'ihf.component.routines.loading');
            }
        });
    }
    // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    async cronControlStart(id, runningId) {
        const update = {
            running: true,
            startDate: Date.now(),
            jobRunningId: runningId,
            finishedDate: '',
        };
        return await this.model.findOneAndUpdate({
            jobId: id,
            running: false,
        }, update, {
            new: true
        });
    }
    // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    async cronControlFinish(id, runningId) {
        const update = {
            running: false,
            startDate: Date.now(),
            finishedDate: Date.now(),
        };
        return await this.model.findOneAndUpdate({
            jobId: id,
            jobRunningId: runningId,
            running: true,
        }, update, {
            new: true
        });
    }
    // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    async getCronControl(id) {
        return await this.model.findOne({
            jobId: id,
        });
    }
    // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    transStart(id) {
        let apmTransaction = null;
        if (index_1.apm)
            apmTransaction = index_1.apm.startTransaction(id, 'Routines');
        return apmTransaction;
    }
    // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    async transEnd(trans) {
        if (trans)
            trans.end();
    }
}
exports.Cron = Cron;
//# sourceMappingURL=index.js.map