"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Loader = void 0;
const index_1 = require("../index");
const component_1 = require("./component");
const models_1 = require("./models");
const router_1 = require("./router");
const cron_1 = require("./cron");
const tasks_1 = require("./tasks");
const path_1 = __importDefault(require("path"));
const fs_1 = __importDefault(require("fs"));
class Loader {
    constructor(options) {
        this.options = options;
        this.componentsPath = path_1.default.join(process.cwd(), options.framework.components);
    }
    /**
     * getComponents
     */
    async getComponents() {
        let count = 0;
        const components = [];
        return new Promise((resolve, reject) => {
            // The component folder exists?
            if (!fs_1.default.existsSync(this.componentsPath)) {
                reject(`Components folder: ${this.componentsPath} not found`);
            }
            // Read the component folder
            const componentsFolder = fs_1.default.readdirSync(this.componentsPath);
            // Check if not empty
            if (componentsFolder.length === 0) {
                reject(`No components found at ${this.componentsPath}`);
            }
            // Loop the folder
            componentsFolder.forEach(async (component, index) => {
                count += 1;
                const componentPath = path_1.default.join(this.componentsPath, component);
                const componentLoad = await Promise.resolve().then(() => __importStar(require(componentPath)));
                const componentModule = componentLoad.default;
                // Check if what we're importing is a Component instance
                if (!(componentModule instanceof component_1.Component)) {
                    return reject(`${component} is not a instance of Component`);
                }
                // Set the component alis, we're going to use it later for the routes
                componentModule.alias = component;
                componentModule.path = componentPath;
                components.push(componentModule);
                if (count === index + 1)
                    return resolve(components);
            });
        });
    }
    /**
     *
     */
    async start() {
        // Load the global models folder
        if (this.options.database.enabled) {
            await new models_1.Models(path_1.default.join(process.cwd(), this.options.framework.models)).load();
        }
        // Load the components
        const components = await this.getComponents();
        // Lets load the components
        for (let i = 0; components.length > i; i += 1) {
            const component = components[i];
            index_1.logger.debug(`Loading component '${component.alias}'`, 'ihf.component.loading');
            // Load the component level models
            if (this.options.database.enabled) {
                await new models_1.Models(path_1.default.join(component.path, 'models')).load();
            }
            // If the server feature is enabled
            if (this.options.server.enabled &&
                (component.routes && component.routes.length > 0) ||
                (component.proxies && component.proxies.length > 0)) {
                // Load the routes
                await new router_1.Router(component.routes, component.proxies, component.routesMiddleware, component.alias);
            }
            // Routines
            if (component.routines && component.routines.length > 0) {
                // Load the routines
                let cronModel = false;
                if (this.options.database.enabled) {
                    cronModel = index_1.database.model('cron', cron_1.schema);
                }
                await new cron_1.Cron(component.routines, cronModel);
            }
            // Tasks
            if (this.options.tasks.enabled && component.tasks && component.tasks.length > 0) {
                await new tasks_1.Tasks().load(component.tasks);
            }
        }
        return;
    }
}
exports.Loader = Loader;
//# sourceMappingURL=index.js.map