"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    Object.defineProperty(o, k2, { enumerable: true, get: function() { return m[k]; } });
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Plugins = void 0;
/* eslint-disable global-require */
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
const index_1 = require("../../index");
/**
 * Plugins Class
 *
 * @export
 * @class Plugins
 */
class Plugins {
    /**
     *Creates an instance of Plugins.
     * @param {string} pluginPath
     * @memberof Plugins
     */
    constructor(pluginsFolderPath) {
        this.pluginsPaths = [];
        this.plugins = {};
        this.pluginsFolderPath = path_1.default.join(process.cwd(), pluginsFolderPath);
    }
    /**
     * Get Plugins
     *
     * @private
     * @returns {string[]}
     * @memberof Plugins
     */
    getPlugins() {
        if (!fs_1.default.existsSync(this.pluginsFolderPath)) {
            index_1.logger.debug(`Plugins folder not found in path ${this.pluginsFolderPath}`, 'ihf.plugins.loading.folder.notFound');
            return;
        }
        this.pluginsPaths =
            fs_1.default.readdirSync(this.pluginsFolderPath).filter(plugin => plugin.match(/js$/));
        index_1.logger.debug(`Found ${this.pluginsPaths.length} plugins`, 'ihf.plugins.loading.folder.count');
    }
    /**
     * Load the plugin module
     *
     * Load and check if the plugin module is a promise
     *
     * @param {string} plugin
     * @returns
     * @memberof Plugins
     */
    async loadPlugins() {
        for (let i = 0; this.pluginsPaths.length > i; i += 1) {
            const plugin = this.pluginsPaths[i];
            const pluginName = plugin.replace('.js', '');
            const pluginModulePath = path_1.default.join(this.pluginsFolderPath, plugin);
            const pluginModule = await Promise.resolve().then(() => __importStar(require(pluginModulePath)));
            if (!pluginModule.default) {
                index_1.logger.error(`${pluginModulePath} must be exported as default`, 'ihf.plugins.loading.error');
                return;
            }
            if (pluginModule.default instanceof Promise === false) {
                index_1.logger.error(`${pluginModulePath} must be a promise`, 'ihf.plugins.loading.error');
                return;
            }
            this.plugins[pluginName] = await pluginModule.default;
            index_1.logger.debug(`Plugin ${pluginName} loaded`, 'ihf.plugins.loading.success');
        }
    }
    /**
     *
     *
     * @returns
     * @memberof Plugins
     */
    // eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
    async start() {
        this.getPlugins();
        await this.loadPlugins();
        return this.plugins;
    }
}
exports.Plugins = Plugins;
//# sourceMappingURL=index.js.map