"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Server = void 0;
const express_1 = __importDefault(require("express"));
const body_parser_1 = __importDefault(require("body-parser"));
const cors_1 = __importDefault(require("cors"));
// import helmet from 'helmet';
const index_1 = require("../index");
class Server {
    /**
     * Creates an instance of Server.
     * @param {ServerOptions} options
     * @memberof Server
     */
    constructor(options) {
        this.healthStatus = 400;
        this.enabled = options.enabled;
        this.headers = options.headers;
        if (!this.enabled) {
            index_1.logger.debug('Server not enabled', 'ihf.server.notEnabled');
            return;
        }
        this.app = express_1.default();
        this.app.use(cors_1.default());
        this.app.use(body_parser_1.default.json({ limit: '50mb' }));
        // Set the port
        this.app.set('port', options.http.port);
        // Set the JWT Secret
        this.app.set('jwt_secret', options.jwt);
        // Set the health check endpoint
        this.app.get('/healthz', (req, res) => {
            res.status(this.healthStatus).json({ status: this.healthStatus });
        });
        this.app.get('/cache', (req, res) => {
            res.json(index_1.CacheHelper.getInfo());
        });
        // TODO: implement this
        // this.app.use((req: RequestPrivate, res: Response, next: Next) => {
        //   req.method;
        //   logger.info('', 'server.audit.action', {
        //   });
        //   next();
        // });
        // TODO: Implement helmet better
        // this.app.use(helmet());
        if (this.headers) {
            this.app.use((req, res, next) => {
                this.headers.forEach((header) => {
                    res.header(header.prop, header.value);
                });
                next();
            });
        }
    }
    async start() {
        return new Promise((resolve, reject) => {
            if (!this.enabled)
                resolve(null);
            const port = this.app.get('port');
            try {
                this.listen = this.app.listen(port, () => {
                    index_1.logger.debug(`Server started at port ${port}`, 'ihf.server.started');
                    resolve(this);
                });
            }
            catch (error) {
                reject(error);
            }
        });
    }
    /**
     * Healt status route ok
     * @todo Improve the return, put some information about the process
     * @memberof Server
     */
    healthz() {
        this.healthStatus = 200;
    }
}
exports.Server = Server;
//# sourceMappingURL=index.js.map