"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.isNumberAndHigherOrEqualsToZero = exports.isFinite = exports.isNumber = void 0;
/* eslint-disable @typescript-eslint/explicit-module-boundary-types */
const lodash_1 = __importDefault(require("lodash"));
/**
 * Checks if `value` is classified as a Number primitive or object.
 *
 * Note: To exclude Infinity, -Infinity, and NaN, which are classified as numbers, use the isFinite method.
 *
 * @param value The `value` to check.
 * @return Returns true if `value` is correctly classified, else false.
 */
function isNumber(value) {
    return lodash_1.default.isNumber(value);
}
exports.isNumber = isNumber;
/**
 * Checks if `value` is a finite primitive number.
 *
 * Note: This method is based on Number.isFinite.
 *
 * @param value The value to check.
 * @return Returns true if `value` is a finite number, else false.
 */
function isFinite(value) {
    return lodash_1.default.isFinite(value);
}
exports.isFinite = isFinite;
/**
 * Checks if `value` is a finite primitive number.
 *
 * Note: This method is based on Number.isFinite.
 *
 * @param value The value to check.
 * @return Returns true if `value` is a finite number, else false.
 */
function isNumberAndHigherOrEqualsToZero(value) {
    return isNumber(value) && value >= 0;
}
exports.isNumberAndHigherOrEqualsToZero = isNumberAndHigherOrEqualsToZero;
//# sourceMappingURL=numberUtils.js.map