/**
 * Checks if `value` is classified as a String primitive or object.
 *
 * @param value The value to check.
 * @returns Returns true if value is correctly classified, else false.
 *
 * @example
 *
 * isString(null);
 * // => false
 * isString(undefined);
 * // => false
 * isString('');
 * // => true
 * isString(' ');
 * // => true
 * isString('test');
 * // => true
 * isString(new String());
 * // => true
 * isString(new String(''));
 * // => true
 * isString(new String(' '));
 * // => true
 * isString(new String('teste'));
 * // => true
 * isString(1);
 * // => false
 * isString({});
 * // => false
 * isString([]);
 * // => false
 */
export declare function isString(value?: any): boolean;
/**
 * Checks if `value` is null, undefined or is classified as a String primitive or object and is empty ('').
 *
 * @param value The value to check.
 * @returns Returns true if `value` is null, undefined or is correctly classified and is empty (''), else false.
 *
 * @example
 *
 * isEmpty(null);
 * // => true
 * isEmpty(undefined);
 * // => true
 * isEmpty('');
 * // => true
 * isEmpty(' ');
 * // => false
 * isEmpty('test');
 * // => false
 * isEmpty(new String());
 * // => true
 * isEmpty(new String(''));
 * // => true
 * isEmpty(new String(' '));
 * // => false
 * isEmpty(new String('teste'));
 * // => false
 * isEmpty(1);
 * // => false
 * isEmpty({});
 * // => false
 * isEmpty([]);
 * // => false
 */
export declare function isEmpty(value?: string): boolean;
/**
 * Checks if `value` is null, undefined or is classified as a String primitive or object and is empty ('') or whitespace only.
 *
 * @param value The value to check.
 * @returns Returns true if `value` is correctly classified and is empty ('') or whitespace only, else false.
 *
 * @example
 *
 * isBlank(null);
 * // => true
 * isBlank(undefined);
 * // => true
 * isBlank('');
 * // => true
 * isBlank(' ');
 * // => true
 * isBlank('test');
 * // => false
 * isBlank(new String());
 * // => true
 * isBlank(new String(''));
 * // => true
 * isBlank(new String(' '));
 * // => true
 * isBlank(new String('teste'));
 * // => false
 * isBlank(1);
 * // => false
 * isBlank({});
 * // => false
 * isBlank([]);
 * // => false
 */
export declare function isBlank(value?: string): boolean;
/**
 * Checks if `value` is classified as a String primitive or object, if yes then concatenate all the digits (0-9) in `value` and return it.
 *
 * @param value The value to check.
 * @returns Returns only digits (0-9) of `value`.
 * @example
 *
 * getDigits(null);
 * // => null
 * getDigits(undefined);
 * // => null
 * getDigits('');
 * // => ''
 * getDigits(' ');
 * // => ''
 * getDigits('test');
 * // => ''
 * getDigits('123.456.789-01');
 * // => '12345678901'
 * getDigits(new String());
 * // => ''
 * getDigits(new String(''));
 * // => ''
 * getDigits(new String(' '));
 * // => ''
 * getDigits(new String('teste'));
 * // => ''
 * getDigits(1);
 * // => null
 * getDigits({});
 * // => null
 * getDigits([]);
 * // => null
 */
export declare function getDigits(value?: string): string;
/**
 * Deletes all whitespaces in `value` if it is classified as a String primitive or object, and return `value` without whitespaces.
 *
 * @param value The value to check.
 * @returns Returns the `value` without whitespaces, null if `value` is not correctly classified.
 * @example
 *
 * deleteWhitespace(null);
 * // => null
 * deleteWhitespace(undefined);
 * // => null
 * deleteWhitespace('');
 * // => ''
 * deleteWhitespace(' ');
 * // => ''
 * deleteWhitespace('test');
 * // => 'test'
 * deleteWhitespace('123.  789-01');
 * // => '123.789-01'
 * deleteWhitespace(new String());
 * // => ''
 * deleteWhitespace(new String(''));
 * // => ''
 * deleteWhitespace(new String(' '));
 * // => ''
 * deleteWhitespace(new String('te  st'));
 * // => 'test'
 * deleteWhitespace(1);
 * // => null
 * deleteWhitespace({});
 * // => null
 * deleteWhitespace([]);
 * // => null
 *
 */
export declare function deleteWhitespace(value?: string): string;
